/*!
* \file controleur.c
* \brief Fichier contenant le code des fonctions du controleur.
*/

#include <stdio.h>
#include <stdlib.h>

#include "partie.h"
#include "joueur.h"
#include "joueurList.h"
#include "case.h"
#include "personnage.h"
#include "classe.h"
#include "gamePackage.h"
#include "roxml.h"

Partie * partieGlobale;
Game_Package packGlobal;

  /*!
 * \fn void initJeu()
 * \brief La fonction initialise les variable globales du package du jeu et de la Partie
 */
void initJeu(){
    partieGlobale = initPartie();
    packGlobal = Construire_Package();
}

/*!
 * \fn void ajouterUnJoueur(char * nomDuJoueur, EtatsJeu * etat)
 * \brief Fonction ajoutant un Joueur  la Partie et faisant passer la partie  l'tat suivant.
 *        Si le joueur n'a pas correctement t ajout, l'tat reste le mme.
 *
 * \param Le nom du joueur  ajouter  la partie
 */
 void ajouterUnJoueur(char * nomDuJoueur, EtatsJeu * etat){
    Joueur * j = nouveauJoueur();
    if(j!=NULL){
        setNomJoueur(j,nomDuJoueur);
        if(addParticipant(partieGlobale,j)==0){
            *etat =LANCEMENT;
        }
        else{
            *etat=SAISIE_JOUEURS;
        }
    }
    else{
        *etat=SAISIE_JOUEURS;
    }
 }

  /*!
 * \fn  int nbClasses()
 * \brief Fonction renvoyer le nombre de classes contenues dans le package du jeu
 *
 * \return le nombre de classes contenues dans le package du jeu
 */
 int nbClasses(){
    return getNbClasses(packGlobal);
}

 /*!
 * \fn char ** obtenirNomsClasses()
 * \brief Fonction renvoyant un tableau de chaine de caractres contenant les noms des Classes.
 *        L'ordre et l'index des noms dans le tableau correspond  l'ordre dans lequel ils sont dfinis
 *        dans le fichier XML.
 *
 * \return un tableau de chaine de charactres (char**).
 */
 char ** obtenirNomsClasses(){
    int i;
    //Allocation du tableau contenant les chaines de charactres
    char ** tabNomClasses=malloc(nbClasses()*sizeof(char[TAILLE_NOMS]));
    for(i=0;i<nbClasses();i++){
        tabNomClasses[i]= malloc(TAILLE_NOMS*sizeof(char));
    }
    //Copie des noms de classes dans le tableau
    for(i=0;i<nbClasses();i++){
        strncpy(tabNomClasses[i],packGlobal.Classes_Package[i].nom, TAILLE_NOMS);
    }
    return tabNomClasses;
 }

  /*!
 * \fn char ** obtenirSkinsClasses()
 * \brief Fonction renvoyant un tableau de chaine de caractres contenant le chemin vers les Skins des Classes.
 *        L'ordre et l'index des noms dans le tableau correspond  l'ordre dans lequel ils sont dfinis
 *        dans le fichier XML.
 *        Ici le chemin du Skin renvoy est celui du "default".
 *
 * \return un tableau de chaine de charactres (char**).
 */
 char ** obtenirSkinsClasses(){
    int i;
    //Allocation du tableau contenant les chaines de charactres
    char ** tabSkinsClasses = malloc((getNbClasses(packGlobal))*sizeof(char *));
    for(i=0;i<getNbClasses(packGlobal);i++){
        tabSkinsClasses[i]= malloc(TAILLE_CHEMIN*sizeof(char));
    }
        //Copie des chemin des skins dans le tableau
    for(i=0;i<getNbClasses(packGlobal);i++){
        strncpy(tabSkinsClasses[i],packGlobal.Classes_Package[i].skins.charac_default, TAILLE_CHEMIN);
    }
    return tabSkinsClasses;
 }

   /*!
 * \fn void freeClasses()
 * \brief La fonction libre un tableau de chaines de charactres allou pour stocker les informations sur les classes.
 *
 * \param
 */
  void freeClasses(char ** tab){
    int i;
    for(i=0;i<nbClasses();i++){
        free(tab[i]);
    }
    free(tab);
}

   /*!
 * \fn  int nbCartes()
 * \brief Fonction renvoyer le nombre de cartes contenues dans le package du jeu
 *
 * \return le nombre de cartes contenues dans le package du jeu
 */
int nbCartes(){
    return getNbCartes(packGlobal);
}

  /*!
 * \fn char ** obtenirNomsCartes()
 * \brief Fonction renvoyant un tableau de chaine de caractres contenant les noms des Cartes.
 *        L'ordre et l'index des noms dans le tableau correspond  l'ordre dans lequel ils sont dfinis
 *        dans le fichier XML.
 *
 * \return un tableau de chaine de charactres (char**).
 */
char ** obtenirNomsCartes(){
    int i;
    //Allocation du tableau contenant les chaines de charactres
    char ** tabNomsCartes = malloc((getNbCartes(packGlobal))*sizeof(char *));
    for(i=0;i<getNbCartes(packGlobal);i++){
        tabNomsCartes[i]= malloc(TAILLE_CHEMIN*sizeof(char));
    }
    //Copie des noms des cartes dans le tableau
    for(i=0;i<getNbCartes(packGlobal);i++){
        strncpy(tabNomsCartes[i],packGlobal.Cartes_Package->nom, TAILLE_CHEMIN);
    }
    return tabNomsCartes;
}

  /*!
 * \fn char ** obtenirDescriptionCarte()
 * \brief Fonction renvoyant un tableau de chaine de caractres contenant les descriptions des Cartes.
 *        L'ordre et l'index des descriptions dans le tableau correspond  l'ordre dans lequel ils sont dfinis
 *        dans le fichier XML.
 *
 * \return un tableau de chaine de charactres (char**).
 */
char ** obtenirDescriptionCarte(){
    int i;
    //Allocation du tableau contenant les chaines de charactres
    char ** tabDescCartes = malloc((getNbCartes(packGlobal))*sizeof(char *));
    for(i=0;i<getNbCartes(packGlobal);i++){
        tabDescCartes[i]= malloc(100*sizeof(char));
    }
    //Copie des descriptions des cartes dans le tableau
    for(i=0;i<getNbCartes(packGlobal);i++){
        strncpy(tabDescCartes[i],packGlobal.Cartes_Package->desc, 100);
    }
    return tabDescCartes;
}

  /*!
 * \fn void freeCartes()
 * \brief La fonction libre un tableau de chaines de charactres allou pour stocker les informations sur la carte.
 *
 * \param
 */
  void freeCartes(char ** tab){
    int i;
    for(i=0;i<nbCartes();i++){
        free(tab[i]);
    }
    free(tab);
}








